@@ -1,4 +1,4 @@
-//@line 41 "/mnt/data/211/toolkit/components/passwordmgr/resources/content/passwordManagerCommon.js"
+//@line 42 "/home/gscrivano/icecat/301/toolkit/components/passwordmgr/content/passwordManagerCommon.js"
 
 /*** =================== INITIALISATION CODE =================== ***/
 
@@ -21,7 +21,8 @@ var showingPasswords = false;
 
 function Startup() {
   // xpconnect to password manager interfaces
-  passwordmanager = Components.classes["@mozilla.org/passwordmanager;1"].getService(Components.interfaces.nsIPasswordManager);
+  passwordmanager = Components.classes["@mozilla.org/login-manager;1"]
+                        .getService(Components.interfaces.nsILoginManager);
 
   // be prepared to reload the display if anything changes
   kObserverService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
@@ -44,13 +45,17 @@ var signonReloadDisplay = {
     if (topic == "signonChanged") {
       if (state == "signons") {
         signons.length = 0;
-        if (lastSignonSortColumn == "host") {
+        if (lastSignonSortColumn == "hostname") {
           lastSignonSortAscending = !lastSignonSortAscending; // prevents sort from being reversed
         }
         LoadSignons();
+        // apply the filter if needed
+        if (document.getElementById("filter") && document.getElementById("filter").value != "") {
+          _filterPasswords();
+        }
       } else if (state == "rejects") {
         rejects.length = 0;
-        if (lastRejectSortColumn == "host") {
+        if (lastRejectSortColumn == "hostname") {
           lastRejectSortAscending = !lastRejectSortAscending; // prevents sort from being reversed
         }
         LoadRejects();
@@ -107,62 +112,42 @@ function DeleteAllFromTree(tree, view, table, deletedTable, removeButton, remove
 function DeleteSelectedItemFromTree
     (tree, view, table, deletedTable, removeButton, removeAllButton) {
 
-  var box = tree.treeBoxObject;
+  // Turn off tree selection notifications during the deletion
+  tree.view.selection.selectEventsSuppressed = true;
 
-  // Remove selected items from list (by setting them to null) and place in
-  // deleted list.  At the same time, notify the tree of the row count changes.
-
-  var selection = box.view.selection;
-  var oldSelectStart = table.length;
-  box.beginUpdateBatch();
-
-  var selCount = selection.getRangeCount();
-  var min = new Object();
-  var max = new Object();
-
-  for (var s = 0; s < selCount; ++s) {
-    selection.getRangeAt(s, min, max);
-    var minVal = min.value;
-    var maxVal = max.value;
-
-    oldSelectStart = minVal < oldSelectStart ? minVal : oldSelectStart;
-
-    var rowCount = maxVal - minVal + 1;
-    view.rowCount -= rowCount;
-    box.rowCountChanged(minVal, -rowCount);
-
-    for (var i = minVal; i <= maxVal; ++i) {
-      deletedTable[deletedTable.length] = table[i];
-      table[i] = null;
-    }
+  // remove selected items from list (by setting them to null) and place in deleted list
+  var selections = GetTreeSelections(tree);
+  for (var s=selections.length-1; s>= 0; s--) {
+    var i = selections[s];
+    deletedTable[deletedTable.length] = table[i];
+    table[i] = null;
   }
 
   // collapse list by removing all the null entries
-  for (var j = 0; j < table.length; ++j) {
-    if (!table[j]) {
+  for (var j=0; j<table.length; j++) {
+    if (table[j] == null) {
       var k = j;
-      while (k < table.length && !table[k])
+      while ((k < table.length) && (table[k] == null)) {
         k++;
-
+      }
       table.splice(j, k-j);
+      view.rowCount -= k - j;
+      tree.treeBoxObject.rowCountChanged(j, j - k);
     }
   }
 
-  box.endUpdateBatch();
-
   // update selection and/or buttons
-  var removeBtn = document.getElementById(removeButton);
-  var removeAllBtn = document.getElementById(removeAllButton);
-
   if (table.length) {
-    removeBtn.removeAttribute("disabled");
-    removeAllBtn.removeAttribute("disabled");
-
-    selection.select(oldSelectStart < table.length ? oldSelectStart : table.length - 1);
+    // update selection
+    var nextSelection = (selections[0] < table.length) ? selections[0] : table.length-1;
+    tree.view.selection.select(nextSelection);
+    tree.treeBoxObject.ensureRowIsVisible(nextSelection);
   } else {
-    removeBtn.setAttribute("disabled", "true");
-    removeAllBtn.setAttribute("disabled", "true");
+    // disable buttons
+    document.getElementById(removeButton).setAttribute("disabled", "true")
+    document.getElementById(removeAllButton).setAttribute("disabled","true");
   }
+  tree.view.selection.selectEventsSuppressed = false;
 }
 
 function GetTreeSelections(tree) {
@@ -234,9 +219,16 @@ function SortTree(tree, view, table, column, lastSortColumn, lastSortAscending,
  * Case insensitive string comparator.
  */
 function CompareLowerCase(first, second) {
+  var firstLower, secondLower;
 
-  var firstLower  = first.toLowerCase();
-  var secondLower = second.toLowerCase();
+  // Are we sorting nsILoginInfo entries or just strings?
+  if (first.hostname) {
+    firstLower  = first.hostname.toLowerCase();
+    secondLower = second.hostname.toLowerCase();
+  } else {
+    firstLower  = first.toLowerCase();
+    secondLower = second.toLowerCase();
+  }
 
   if (firstLower < secondLower) {
     return -1;
